const { logger } = require("../../utils/logger")
const ResponseHelpers =require('../../Helper/ResponseHelper')
const {validations, removeSpace} = require("../../utils/validations")
const { insertOrganizationService, getOrganizationService, updateOrganizationService, deleteOrganizationService, updateOrganizationStatusService } = require("./organizations.services")
const { REQUIRED_VALIDATION_MESSAGE, EMAIL_VALIDATION_MESSAGE, MOBILE_VALIDATION_MESSAGE, DATABASE_NAME_VALIDATION_MESSAGE, GST_VALIDATION_MESSAGE, SPACE_NOT_VALIADTION_MESSAGE } = require("../../constant")


const insertOrganizationController =async(req,res)=>{
    try {
        const organizationdata = removeSpace(req.body)
        // REQUIRED VALIDATION
        const firstnameValidation =  validations("required",organizationdata.firstname) 
        const lastnameValidation = validations("required",organizationdata.lastname )
        const companyNameValidation = validations("required",organizationdata.company_name)
        const emailValidation = validations("required",organizationdata.email)
        const phoneValidation = validations("required",organizationdata.phone)
        const dbnameValidation = validations("required",organizationdata.db_name)
        const passwordVailadation =validations("required",organizationdata.password)
        const domainurlValidation =validations("required",organizationdata.domain_baseurl)
        // REGEX VALIDATION
        const EmailValidation = validations("email",organizationdata.email,EMAIL_VALIDATION_MESSAGE)
        const PhoneValidation = validations("mobile",organizationdata.phone,MOBILE_VALIDATION_MESSAGE)
        const DatabaseNameValidation = validations("database",organizationdata.db_name,DATABASE_NAME_VALIDATION_MESSAGE)
        const DomainValidation = validations("domain",organizationdata.domain_baseurl,SPACE_NOT_VALIADTION_MESSAGE)
    
        if(firstnameValidation.status != 0 || lastnameValidation.status != 0 || companyNameValidation.status != 0 || emailValidation.status != 0 ||phoneValidation.status != 0 || dbnameValidation.status != 0 || passwordVailadation.status != 0 || domainurlValidation.status != 0 ){
            ResponseHelpers.BadRequest(res,REQUIRED_VALIDATION_MESSAGE)
        }else if(EmailValidation.status != 0 ){
            ResponseHelpers.BadRequest(res,EmailValidation.description)
        }else if(PhoneValidation.status != 0){
            ResponseHelpers.BadRequest(res,PhoneValidation.description)
        }else if(DatabaseNameValidation.status != 0){
            ResponseHelpers.BadRequest(res,DatabaseNameValidation.description)
        }else if(DomainValidation.status !=0){
            ResponseHelpers.BadRequest(res,DomainValidation.description)
        }else{
            const data= await insertOrganizationService(organizationdata)
            if(data.status == 1){
                ResponseHelpers.Success(res,data.data,data.description)
            }else if (data.status == 2){
                ResponseHelpers.InternalServerError(res,data.description)
            }else if(data.status == 3){
                ResponseHelpers.BadRequest(res,data.description)
            }else{
                ResponseHelpers.Error(res,data.description)
            }
        }
       
    } catch (error) {
        logger.error("----------------------------------- insertOrganizationController -------------------------------------------")
        logger.error(error)
        ResponseHelpers.InternalServerError(res,"Something Went Wrong,please Try Again..!")
    }
}

const getOrganizationController = async(req,res)=>{
    try {
        const organiationdata =req.body
        const data = await getOrganizationService(organiationdata)
        if(data.status == 1){
            ResponseHelpers.Success(res,data.data,data.description)
        }else if(data.status == 2){
            ResponseHelpers.InternalServerError(res,data.description)
        }else{
            ResponseHelpers.Error(res,data.description)
        }
    } catch (error) {
        logger.error("-------------------------------------- getOrganizationController --------------------------------------")
        logger.error(error)
        ResponseHelpers.InternalServerError(res,"Something Went Wrong,Please Try Again..!")
    }
}

const updateOrganizationController = async (req,res)=>{
    try {
        const organizationdata = removeSpace(req.body)
        // REQUIRED VALIDATION
        const firstnameValidation =  validations("required",organizationdata.firstname) 
        const lastnameValidation = validations("required",organizationdata.lastname )
        const companyNameValidation = validations("required",organizationdata.company_name)
        const emailValidation = validations("required",organizationdata.email)
        const phoneValidation = validations("required",organizationdata.phone)
        const domainurlValidation =validations("required",organizationdata.domain_baseurl)
        // REGEX VALIDATION
        const EmailValidation = validations("email",organizationdata.email,EMAIL_VALIDATION_MESSAGE)
        const PhoneValidation = validations("mobile",organizationdata.phone,MOBILE_VALIDATION_MESSAGE)
        const DomainValidation = validations("domain",organizationdata.domain_baseurl,SPACE_NOT_VALIADTION_MESSAGE)

    
        if(firstnameValidation.status != 0 || lastnameValidation.status != 0 || companyNameValidation.status != 0 || emailValidation.status != 0 ||phoneValidation.status != 0  || domainurlValidation.status != 0 ){
            ResponseHelpers.BadRequest(res,REQUIRED_VALIDATION_MESSAGE)
        }else if(EmailValidation.status != 0 ){
            ResponseHelpers.BadRequest(res,EmailValidation.description)
        }else if(PhoneValidation.status != 0){
            ResponseHelpers.BadRequest(res,PhoneValidation.description)
        }else if(DomainValidation.status !=0){
            ResponseHelpers.BadRequest(res,DomainValidation.description)
        }else{
            const data= await updateOrganizationService(organizationdata)
            if(data.status == 1){
                ResponseHelpers.Success(res,data.data,data.description)
            }else if(data.status == 2){
                ResponseHelpers.InternalServerError(res,data.description)
            }else if(data.status == 3){
                ResponseHelpers.BadRequest(res,data.description)
            }else{
                ResponseHelpers.Error(res,data.description)
            }
        }
       
    } catch (error) {
        logger.error("----------------------------------- updateOrganizationController ---------------------------------------")
        logger.error(error)
        ResponseHelpers.InternalServerError(res,"Something Went Wrong,Please Try Again..!")
    }
}

const deleteOrganizationController = async (req,res)=>{
    try {
        const organiationdata = req.body
        const data = await deleteOrganizationService(organiationdata)
        if(data.status == 1){
            ResponseHelpers.Success(res,data.data,data.description)
        }else if(data.status == 2){
            ResponseHelpers.InternalServerError(res,data.description)
        }else {
            ResponseHelpers.Error(res,data.description)
        }
    } catch (error) {
        logger.error("------------------------------------ deleteOrganizationController -----------------------------------------")
        logger.error(error)
        ResponseHelpers.InternalServerError(res,"Something Went Wrong,Please Try Again..!")
    }
   
}

const updateOrganizationStatusController = async (req,res)=>{
    try {
        const statusdata = req.body;
        const data = await updateOrganizationStatusService(statusdata)
        if(data.status == 1){
            ResponseHelpers.Success(res,data.data,data.description)
        }else if(data.status == 2){
            ResponseHelpers.InternalServerError(res,data.description)
        }else if(data.status == 3){
            ResponseHelpers.BadRequest(res,data.description)
        }else{
            ResponseHelpers.Error(res,data.description)
        }
    } catch (error) {
       logger.error("-------------------------------------------- updateOrganizationStatusController -------------------------------------------") 
       logger.error(error)
       ResponseHelpers.InternalServerError(res,data.description)
    }
}

module.exports = { 
    insertOrganizationController,
    getOrganizationController ,
    updateOrganizationController,
    deleteOrganizationController,
    updateOrganizationStatusController}