const { logger } = require("../../utils/logger")
const ResponseHelpers = require("../../Helper/ResponseHelper");
const { insertStoreService, getStoreService, updateStoreService,  updateStoreStatusService, getExpiredStoreDetailsService } = require("./store.services");
const { validations } = require("../../utils/validations");
const { REQUIRED_VALIDATION_MESSAGE } = require("../../constant");

const insertStoreController = async (req,res)=>{
    try {
        const storedata = req.body;
        const storenameValidation = validations("required",storedata.store_name)
        const purchaseDateValidation = validations("required",storedata.purchase_date)
        if(storenameValidation.status !=0 || purchaseDateValidation.status !=0){
            ResponseHelpers.BadRequest(res,REQUIRED_VALIDATION_MESSAGE)
        }else{
            const data = await insertStoreService(storedata)
            if(data.status == 1){
                ResponseHelpers.Success(res,data.data,data.description)
            }else if(data.status == 2){
                ResponseHelpers.InternalServerError(res,data.description)
            }else {
                ResponseHelpers.Error(res,data.description)
            }
        }       
    } catch (error) {
        logger.error("--------------------------------- insertStoreController ----------------------------------")
        logger.error(error)
        ResponseHelpers.InternalServerError(res,"Something Went Wrong,Please Try Again..!")

    }
}


const getStoreController = async (req,res)=>{
    try {
        const storedata = req.body;
        const data = await getStoreService(storedata)
        if(data.status == 1){
            ResponseHelpers.Success(res,data.data,data.description)
        }else if(data.status == 2){
            ResponseHelpers.InternalServerError(res,data.description)
        }else{
            ResponseHelpers.Error(res,data.description)
        }
    } catch (error) {
        logger.error("-----------------------------------getStoreController ---------------------------------- ")
        logger.error(error)
        ResponseHelpers.InternalServerError(res,"Something Went Wrong,Please Try Again...")
    }
}


const updateStoreController = async(req,res)=>{
    try {
        const storedata = req.body;
        const storenameValidation = validations("required",storedata.store_name)
        const purchaseDateValidation = validations("required",storedata.purchase_date)

        if(storenameValidation.status !=0 || purchaseDateValidation.status !=0){
            ResponseHelpers.BadRequest(res,REQUIRED_VALIDATION_MESSAGE)
        }else{
            const data =await updateStoreService(storedata)
            if(data.status == 1){
                ResponseHelpers.Success(res,data.data,data.description)
            }else if(data.status == 2){
                ResponseHelpers.InternalServerError(res,data.description)
            }else if(data.status == 3){
                ResponseHelpers.BadRequest(res,data.description)
            }else{
                ResponseHelpers.Error(res,data.description)
            }
        }       
    } catch (error) {
        logger.error("----------------------------- updateStoreController ---------------------------")
        logger.error(error)
        ResponseHelpers.InternalServerError(res,"Something Went Wrong,Please Try Again")
    }
}


const updateStoreStatusController = async (req,res)=>{
    try {
        const statusdata = req.body;
        const data = await updateStoreStatusService(statusdata)
        if(data.status == 1){
            ResponseHelpers.Success(res,data.data,data.description)
        }else if(data.status == 2){
            ResponseHelpers.InternalServerError(res,data.description)
        }else if(data.status == 3){
            ResponseHelpers.BadRequest(res,data.description)
        }else{
            ResponseHelpers.Error(res,data.description)
        }
    } catch (error) {
       logger.error("-------------------------------------------- updateStoreStatusController -------------------------------------------") 
       logger.error(error)
       ResponseHelpers.InternalServerError(res,data.description)
    }
}

const getExpiredStoreDetailsController = async (req,res)=>{
    try {
        const storedata = req.body
        const data = await getExpiredStoreDetailsService(storedata)
        if(data.status == 1){
            ResponseHelpers.Success(res,data.data,data.description)
        }else{
            ResponseHelpers.Error(res,data.description)
        }
    } catch (error) {
        logger.error("---------------------------------- getExpiredStoreDetailsController ---------------------------------------")
        logger.error(error)
        ResponseHelpers.InternalServerError(res,"Something Went Wrong,Please Try Again..!")
    }
}

module.exports = {insertStoreController,getStoreController,updateStoreController,updateStoreStatusController,getExpiredStoreDetailsController}