const { logger } = require("../../utils/logger")
const ResponseHelpers =require("../../Helper/ResponseHelper")
const Models = require("../../models/index.models")
const moment = require("moment");
const { Sequelize } = require("sequelize");
const {
    DATABASEUSERNAME,
    DATABASEPASSWORD,
    DATABASEHOST,
  } = require("../../config");
global.orgSequelize = "";



const insertStoreService =async (storedata)=>{
    try {
        const lastrecord = await Models.superadminStoresModel.findOne({
            raw: true,
            limit: 1,
            order: [["store_id", "DESC"]],
          },{where:{org_id:storedata.org_id}});
        const insertstore = await Models.superadminStoresModel.create({
            store_name:storedata.store_name,
            store_no:lastrecord.store_no + 1,
            org_id:storedata.org_id,
            purchase_date:storedata.purchase_date,
            expiry_date:moment(storedata.purchase_date,"DD-MM-YYYY").add(1, 'year').format('DD-MM-YYYY')
        })
        if(insertstore != null){
            
            // CONNECT ORGANIZATION DATABASE
            orgSequelize = await new Sequelize(storedata.db_name, DATABASEUSERNAME, DATABASEPASSWORD, {
                host:DATABASEHOST,
                dialect: "mysql",
                logging:false,
            });
            exports.OrgSequelize  = orgSequelize;

            // ADD STORE PERMISSION IN ORGANIZATION DATABASE TABLE
            const updateStorePermission = await orgSequelize.query(`update organization SET total_store = total_store + 1 WHERE email='${storedata.email}'`)
            if(updateStorePermission != 0){
                return ResponseHelpers.serviceToController(1,insertstore,"Store Insert Successfully...")
            }
        }else{
            return ResponseHelpers.serviceToController(0,[],"Store Not Inserted..!")
        }
    } catch (error) {
        logger.error("--------------------------------- insertStoreService ---------------------------------------- ")
        logger.error(error)
        return ResponseHelpers.serviceToController(2,[],"ERROR FROM insertStoreService SERVICE CATCH")
    }
}


const getStoreService = async (storedata)=>{
    try {
        const startPage = (storedata.page - 1) * storedata.perPage;
        const perPage = storedata.perPage;
  
        const getstoredetails= await Models.database.query(`SELECT * FROM stores WHERE org_id = ${storedata.org_id} ORDER BY store_id DESC LIMIT ${startPage},${perPage}`,{type:Models.QueryTypes.SELECT})
        const countstoredata = await Models.database.query(`SELECT COUNT(store_id) as count FROM stores WHERE org_id = ${storedata.org_id}`,{type:Models.QueryTypes.SELECT})

        const data={
            data:getstoredetails,
            count:countstoredata[0].count
        }

        if(getstoredetails != null){
            return ResponseHelpers.serviceToController(1,data,"Store Get Successfully...")
        }else{
            return ResponseHelpers.serviceToController(0,[],"Store Not Get..!")
        }

    } catch (error) {
        logger.error("------------------------------------------ getStoreService --------------------------------------")
        logger.error(error)
        return ResponseHelpers.serviceToController(2,[],"ERROR FROM getStoreService SERVICE CATCH")
    }
} 

const updateStoreService =async (storedata)=>{
    try {
        const updateStoredata = await Models.superadminStoresModel.update({
            store_name:storedata.store_name,
            purchase_date:storedata.purchase_date,
            expiry_date:moment(storedata.purchase_date,"DD-MM-YYYY").add(1, 'year').format('DD-MM-YYYY')
        },
        {
            where:{store_id:storedata.store_id}
        })
        if(updateStoredata != 0){
            return ResponseHelpers.serviceToController(1,updateStoredata,"Store Update Syccessfully...")
        }else{
            return ResponseHelpers.serviceToController(3,[],"You Have Not Made Any Changes")
        }
    } catch (error) {
        logger.error("-------------------------------------- updateStoreService ---------------------------------------")
        logger.error(error)
        return ResponseHelpers.serviceToController(2,[],"ERROR FROM updateStoreService SERVICE CATCH")
       
    }
}

const updateStoreStatusService = async (storedata)=>{
try {
    const updatestatus =await Models.database.query(`UPDATE stores SET status = ${storedata.status} WHERE store_id =${storedata.store_id}`,{type:Models.QueryTypes.UPDATE})
    const statusname = storedata.status == 1 ? "Active" : "Deactive";

    // CONNECT ORGANIZATION DATABASE
    orgSequelize = await new Sequelize(storedata.db_name, DATABASEUSERNAME, DATABASEPASSWORD, {
        host: DATABASEHOST,
        dialect: "mysql",
        logging:false,
    });
    exports.OrgSequelize  = orgSequelize;
    let orgIndexModel = require("../../orgModels/orgindex.models")

    // UPDATE STORE STATUS IN ORGANIZATION DATABASE TABLE
    const updateStoreStatus = await orgIndexModel.storesModel.update({
        status : storedata.status
    },{where:{store_id:storedata.store_no}})

    if(updatestatus != 0 || updateStoreStatus != 0 ){
        return ResponseHelpers.serviceToController(1,updatestatus,`Store ${statusname} Successfully...`)
    }else{
        return ResponseHelpers.serviceToController(0,[],`Store Not ${statusname}..!`)
    }

} catch (error) {
    logger.error("-------------------------------------- updateStoreStatusService -------------------------------------------------- ")
    logger.error(error)
    return ResponseHelpers.serviceToController(2,[],"ERROR FROM updateStoreStatusService SERVICE CATCH")

}
}

const getExpiredStoreDetailsService = async (storedata) =>{
    try {
        const startPage = (storedata.page - 1) * storedata.perPage;
        const perPage = storedata.perPage;

        const getstoredetails = await Models.database.query(`SELECT stores.*,organization.firstname,organization.lastname,organization.company_name, DATEDIFF(STR_TO_DATE(stores.expiry_date, '%d-%m-%Y'), STR_TO_DATE('${moment().format("DD-MM-YYYY")}', '%d-%m-%Y')) AS days_left        
                                                            FROM stores INNER JOIN organization ON stores.org_id = organization.org_id WHERE STR_TO_DATE(stores.expiry_date, '%d-%m-%Y') >= STR_TO_DATE('${moment().format("DD-MM-YYYY")}', '%d-%m-%Y') AND
                                                            STR_TO_DATE(stores.expiry_date, '%d-%m-%Y') <= STR_TO_DATE('${moment().add(7, 'days').format('DD-MM-YYYY')}', '%d-%m-%Y') LIMIT ${startPage},${perPage}`,
                                                            {type:Models.QueryTypes.SELECT})

        const countstoredata = await Models.database.query(`SELECT COUNT(store_id) as count FROM stores WHERE STR_TO_DATE(stores.expiry_date, '%d-%m-%Y') >= STR_TO_DATE('${moment().format("DD-MM-YYYY")}', '%d-%m-%Y') AND
                                                            STR_TO_DATE(stores.expiry_date, '%d-%m-%Y') <= STR_TO_DATE('${moment().add(7, 'days').format('DD-MM-YYYY')}', '%d-%m-%Y')`,{type:Models.QueryTypes.SELECT})

        const data={
            data:getstoredetails,
            count:countstoredata[0].count
        }
        
        if(getstoredetails.length > 0 ){
            return ResponseHelpers.serviceToController(1,data,"Expired Store Details Get Successfully...")
        }else{
            return ResponseHelpers.serviceToController(0,[],"Expired Store Details Not Get..!")
        }
    } catch (error) {
        logger.error("------------------------------------ getExpiredStoreDetailsService -------------------------------------")
        logger.error(error)
        return ResponseHelpers.serviceToController(2,[],"ERROR FROM  getExpiredStoreDetailsService SERVICE CATCH")

    }
}


 module.exports = {insertStoreService,getStoreService,updateStoreService,updateStoreStatusService ,getExpiredStoreDetailsService}