const { existsSync, mkdirSync } = require("fs");
const { join } = require("path")
const winston = require("winston");
const winstonDaily = require("winston-daily-rotate-file");
const { YYYY_MM_DD, YYYY_MM_DD_HH_mm_ss } = require("../constant");

// logger folder path
const logDirectory = join(__dirname, "../logs")

// for check , if file or dir exist or not
// if not exists then make
if (!existsSync(logDirectory)) {
    mkdirSync(logDirectory);
}
// logger file format
const loggerFormat = winston.format.printf(info => {
    if (info instanceof Error) {
        return `${info.timestamp}  : ${info.level} : ${info.message} : ${info.stack}`
    }
    return `${info.timestamp} : ${info.level} : ${info.message}`
})
// logger file settings
const logger = winston.createLogger({
    format: winston.format.combine(
        winston.format.timestamp({
            format: YYYY_MM_DD_HH_mm_ss
        }),
        loggerFormat
    ),
    transports: [
        // debug logger settings
        new winstonDaily({
            level: "debug",
            datePattern: YYYY_MM_DD,
            dirname: `${logDirectory}/debug`, //file make as debug in logDirectory
            filename: `%DATE%.log`,
            maxFiles: 30, // 30 Days saved
            json: false,
            zippedArchive: true,
        }),
        // error logger settings
        new winstonDaily({
            level: "error",
            datePattern: YYYY_MM_DD,
            dirname: `${logDirectory}/error`, // file make as error in logDirectory
            filename: `%DATE%.log`,
            maxFiles: 30, //after 30 day make zip file if  zippedArchive is true
            handleExceptions: true,
            json: false,
            zippedArchive: true
        })
    ]
});

logger.add(
    new winston.transports.Console({
        format: winston.format.combine(winston.format.splat(), winston.format.colorize()),
    })
)

const stream = {
    write: (message) => {
        logger.error(message.substring(0, message.lastIndexOf('\n')));
    }
}

module.exports = { logger, stream }